## 0.1.2 (2018-08-09)

- Add CHANGELOG.md
- Install test dependencies through pip install -e '[dev]'
- Install tox for python 3.5 and python 3.6
- Add Makefile

## 0.1.1 (2018-08-08)

- Initial release
